import ec2 = require('@aws-cdk/aws-ec2');
import cdk = require('@aws-cdk/cdk');
/**
 * An EKS cluster
 */
export interface ICluster extends cdk.IConstruct, ec2.IConnectable {
    /**
     * The VPC in which this Cluster was created
     */
    readonly vpc: ec2.IVpcNetwork;
    /**
     * The physical name of the Cluster
     */
    readonly clusterName: string;
    /**
     * The unique ARN assigned to the service by AWS
     * in the form of arn:aws:eks:
     */
    readonly clusterArn: string;
    /**
     * The API Server endpoint URL
     */
    readonly clusterEndpoint: string;
    /**
     * The certificate-authority-data for your cluster.
     */
    readonly clusterCertificateAuthorityData: string;
    /**
     * Export cluster references to use in other stacks
     */
    export(): ClusterImportProps;
}
/**
 * A SecurityGroup Reference, object not created with this template.
 */
export declare abstract class ClusterBase extends cdk.Construct implements ICluster {
    abstract readonly connections: ec2.Connections;
    abstract readonly vpc: ec2.IVpcNetwork;
    abstract readonly clusterName: string;
    abstract readonly clusterArn: string;
    abstract readonly clusterEndpoint: string;
    abstract readonly clusterCertificateAuthorityData: string;
    /**
     * Export cluster references to use in other stacks
     */
    export(): ClusterImportProps;
    private makeOutput;
}
export interface ClusterImportProps {
    /**
     * The VPC in which this Cluster was created
     */
    readonly vpc: ec2.VpcNetworkImportProps;
    /**
     * The physical name of the Cluster
     */
    readonly clusterName: string;
    /**
     * The unique ARN assigned to the service by AWS
     * in the form of arn:aws:eks:
     */
    readonly clusterArn: string;
    /**
     * The API Server endpoint URL
     */
    readonly clusterEndpoint: string;
    /**
     * The certificate-authority-data for your cluster.
     */
    readonly clusterCertificateAuthorityData: string;
    readonly securityGroups: ec2.SecurityGroupImportProps[];
}
